"""Command line interface."""

from .cli import main

if __name__ == "__main__":
    main()
